# Produzione
# DATI
param nM;			# Numero di mesi
set M := 1..nM;		# Insieme dei mesi
set P;				# Insieme di prodotti
param cp {M,P};		# Costi di produzione mensili [/u]
param cs {M};		# Costi di stoccaggio mensili [/u]
param cap_p {M,P};	# Capacita produttiva mensile [u]
param d {M,P};		# Domanda mensile dei prodotti [u]
param Q;			# Capacita del magazzino [u]

# VARIABILI
var x {i in M,j in P} >=0, <=cap_p[i,j];	# Produzione mensile dei prodotti
var y {M,P} >=0;							# Stoccaggio mensile dei prodotti

# VINCOLI
# Vincoli di flusso [unit]. 
subject to Conservazione {i in M, j in P: i>1}:
	y[i-1,j] + x[i,j] - d[i,j] = y[i,j];
# Vincolo di flusso per il primo mese: si assume che le scorte iniziali siano nulle
subject to Conservazione1 {j in P}:
	x[1,j] - d[1,j] = y[1,j];

# Vincolo di capacit del magazzino [unit]
subject to Capacity {i in M}:
  sum {j in P} y[i,j] <= Q;

# OBIETTIVO
# Minimizzare i costi complessivi
minimize z: sum {i in M, j in P} (cp[i,j]*x[i,j] + cs[i]*y[i,j]);

#################
data;
param nM := 12;

set P := X  Y;

param cp: X  Y :=
1	125		240
2	140		245
3	140		230
4	150		230
5	130		225
6	120		220
7	100		215
8	170		240
9	135		225
10	145		235
11	160		240
12	175		250;

param cs :=
1           45
2           45
3           40
4           25
5           20
6           10
7           10
8           10
9           15
10          25
11          35
12          40;

param cap_p: X   Y :=
1		2400	1000
2		2300	900
3		2500	1000
4		2500	1000
5		2450	1000
6		2550	1000
7		2300	900
8		1200	400
9		2200	1000
10		2500	1000
11		2500	1000
12		1800	700;

param d: X  Y :=
1          1800          500
2          1700          400
3          1800          500
4          1800          600
5          1900          700
6          2300          800
7          2500          900
8          2500         1000
9          2000          800
10         1800          800
11         1700          800
12         2000         1000;

param Q := 2500;

end;
